class JsonURLRequired < StandardError
end

class StationListUnavailable < StandardError
end

module AltaBikes
  class City

    attr_accessor :json_url, :stations_root, :station_list, :updated_at

    def initialize(configuration = AltaBikes.configuration)
      raise JsonURLRequired if configuration.json_url.nil?
      @json_url      = configuration.json_url
      @stations_root = configuration.stations_root
      @station_list  = []
    end

    def stations(id = nil)
      get_stations if station_list.empty?

      return station_list.select { |station| station.details[:id] == id }[0] if !id.nil?
      station_list
    end

    def refresh_stations
      @station_list = []
      stations
    end

    def get_stations
      @updated_at = Time.new
      parse_stations(rest_client.get.body)
    rescue SocketError
      raise StationListUnavailable
    end
    private :get_stations

    def parse_stations(raw)
      station_hash = JSON.parse(raw)[stations_root]
      station_hash.each do |raw_station|
        @station_list << AltaBikes::Station.new(raw_station)
      end
    end
    private :parse_stations


    def rest_client
      return nil if json_url.nil?
      RestClient::Resource.new(json_url)
    end
    private :rest_client

  end
end
